(end-of-buffer)
(search-backward "li")
(insert "a")
(save-buffer)
(save-buffers-kill-emacs)
